@@ -14,7 +14,7 @@ except ModuleNotFoundError:
 
 def semplot(mod: Model, filename: str, inspection=None, plot_covs=False,
             plot_exos=True, images=None, engine='dot', latshape='circle',
-            show=False):
+            plot_ests=True, std_ests=False, show=False):
     """
     Draw a SEM diagram.
 
@@ -42,6 +42,12 @@ def semplot(mod: Model, filename: str, inspection=None, plot_covs=False,
     latshape : str, optional
         Graphviz-compaitable shape for latent variables. The default is
         'circle'.
+    plot_ests : bool, optional
+        If True, then estimates are also plotted on the graph. The default is
+        True.
+    std_ests : bool, optional
+        If True and plot_ests is True, then standardized values are plotted
+        instead. The default is False.
     show : bool, optional
         If True, the 
 
@@ -52,10 +58,16 @@ def semplot(mod: Model, filename: str, inspection=None, plot_covs=False,
     """
     if not __GRAPHVIZ:
         raise ModuleNotFoundError("No graphviz module is installed.")
+    if type(mod) is str:
+        mod = Model(mod)
+    if not hasattr(mod, 'last_result'):
+        plot_ests = False
     if inspection is None:
-        inspection = mod.inspect()
+        inspection = mod.inspect(std_est=std_ests)
     if images is None:
         images = dict()
+    if std_ests:
+        inspection['Estimate'] = inspection['Est. Std']
     t = filename.split('.')
     filename, ext = '.'.join(t[:-1]), t[-1]
     g = graphviz.Digraph('G', format=ext, engine=engine)
@@ -87,10 +99,13 @@ def semplot(mod: Model, filename: str, inspection=None, plot_covs=False,
         if (rval not in all_vars) or (~plot_exos and rval in exo_vars) or\
             (rval == '1'):
             continue
-        pval = row['p-value']
-        label = '{:.3f}'.format(float(est))
-        if pval !='-':
-            label += r'\np-val: {:.2f}'.format(float(pval))
+        if plot_ests:
+            pval = row['p-value']
+            label = '{:.3f}'.format(float(est))
+            if pval !='-':
+                label += r'\np-val: {:.2f}'.format(float(pval))
+        else:
+            label = str()
         g.edge(rval, lval, label=label)
     if plot_covs:
         covs = inspection[inspection['op'] == '~~']
@@ -98,10 +113,13 @@ def semplot(mod: Model, filename: str, inspection=None, plot_covs=False,
             lval, rval, est = row['lval'], row['rval'], row['Estimate']
             if lval == rval:
                 continue
-            pval = row['p-value']
-            label = '{:.3f}'.format(float(est))
-            if pval !='-':
-                label += r'\np-val: {:.2f}'.format(float(pval))
+            if plot_ests:
+                pval = row['p-value']
+                label = '{:.3f}'.format(float(est))
+                if pval !='-':
+                    label += r'\np-val: {:.2f}'.format(float(pval))
+            else:
+                label = str()
             g.edge(rval, lval, label=label, dir='both', style='dashed')
     g.render(filename, view=show)
     return g
\ No newline at end of file
